# Référence CLI

## Commandes principales

- `vyro run --app <module:attr>`
- `vyro dev --app <module:attr>`
- `vyro doctor [--strict]`
- `vyro openapi ...`
- `vyro compat ...`
- `vyro release ...`

## Codes de sortie

- `0` : réussite
- `1` : erreur d'exécution/outillage/exécution
- `2` : erreur de validation/utilisation